@@ -317,7 +317,13 @@ class GoodData:
         response = self.session.post(url, json=data)
         while response.status_code != 200:
             sleep(1)
-            target_link = response.json()["uri"][1:]
+            try:
+                target_link = response.json()["uri"][1:]
+            except json.decoder.JSONDecodeError as error:
+                self.logger.error(error)
+                self.logger.error(response.text)
+                self.logger.error("status_code: %d", response.status_code)
+                raise error
             url = _url(self.domain, target_link)
             response = self.session.get(url)
         with open(fname, "w", encoding="utf-8") as fid:
